@@ -1,7 +1,7 @@
 "MCMCtobit" <-
 function(formula, data=parent.frame(), below = 0.0, above = Inf,
            burnin = 1000, mcmc = 10000,
-           thin=1, verbose = FALSE, seed = NA, beta.start = NA,
+           thin=1, verbose = 0, seed = NA, beta.start = NA,
            b0 = 0, B0 = 0, c0 = 0.001, d0 = 0.001, ...) {
 
     # checks
